@@ -1,6 +1,7 @@
 import base64
 import json
 import logging
+import os
 from google.cloud import storage
 from google.cloud.storage.constants import _DEFAULT_TIMEOUT
 from google_crc32c import Checksum
@@ -168,6 +169,7 @@ class GoogleCloudStorageClient:
         :return None:
         """
         blob = self._blob(cloud_path, bucket_name, path_in_bucket)
+        self._create_intermediate_local_directories(local_path)
         blob.download_to_filename(local_path, timeout=timeout)
         logger.debug("Downloaded %r from Google Cloud to %r.", blob.public_url, local_path)
 
@@ -271,6 +273,16 @@ class GoogleCloudStorageClient:
         blob.metadata = self._encode_metadata(metadata)
         blob.patch()
 
+    def _create_intermediate_local_directories(self, local_path):
+        """Create intermediate directories for the given path to a local file if they don't exist.
+
+        :param str local_path:
+        :return None:
+        """
+        directory = os.path.dirname(os.path.abspath(local_path))
+        if not os.path.exists(directory):
+            os.makedirs(directory)
+
     def _encode_metadata(self, metadata):
         """Encode metadata as a dictionary of JSON strings.
 
